@@ -5,6 +5,7 @@ from os.path import join
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple, Union
 
+from hdx.utilities.dateparse import now_utc
 from hdx.utilities.downloader import Download
 from hdx.utilities.uuid import is_valid_uuid
 
@@ -105,7 +106,7 @@ class Resource(HDXObject):
     def get_date_of_resource(
         self,
         date_format: Optional[str] = None,
-        today: datetime = datetime.utcnow(),
+        today: datetime = now_utc(),
     ) -> Dict:
         """Get resource date as datetimes and strings in specified format. If no format
         is supplied, the ISO 8601 format is used. Returns a dictionary containing keys
@@ -115,7 +116,7 @@ class Resource(HDXObject):
 
         Args:
             date_format (Optional[str]): Date format. None is taken to be ISO 8601. Defaults to None.
-            today (datetime): Date to use for today. Defaults to datetime.utcnow.
+            today (datetime): Date to use for today. Defaults to now_utc().
 
         Returns:
             Dict: Dictionary of date information
